==> apache-camel-3.4.0-src.zip: apache-camel-3.4.0/components/camel-rabbitmq/src/test/java/org/apache/camel/component/rabbitmq/qpid/RabbitMQRequeueQpidTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.rabbitmq.qpid;

import org.apache.camel.component.rabbitmq.integration.RabbitMQRequeueIntTest;
import org.junit.AfterClass;
import org.junit.BeforeClass;
import org.junit.Ignore;
import org.junit.Test;

public class RabbitMQRequeueQpidTest extends RabbitMQRequeueIntTest {
    @Override
    public boolean isStartDocker() {
        return false;
    }

    @BeforeClass
    public static void startBroker() throws Exception {
        systemLauncher.startup(createQpidSystemConfig());
    }

    @AfterClass
    public static void stopBroker() {
        systemLauncher.shutdown();
    }

    @Ignore
    @Override
    @Test
    public void testNoRequeueHeaderCausesReject() throws Exception {
    }

    @Ignore
    @Override
    @Test
    public void testNonBooleanRequeueHeaderCausesReject() throws Exception {
    }

    @Ignore
    @Override
    @Test
    public void testFalseRequeueHeaderCausesReject() throws Exception {
    }
}

==> apache-camel-3.5.0-src.zip: apache-camel-3.5.0/components/camel-rabbitmq/src/test/java/org/apache/camel/component/rabbitmq/qpid/RabbitMQRequeueQpidTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.rabbitmq.qpid;

import org.apache.camel.component.rabbitmq.integration.RabbitMQRequeueIntTest;
import org.junit.jupiter.api.AfterAll;
import org.junit.jupiter.api.BeforeAll;
import org.junit.jupiter.api.Disabled;
import org.junit.jupiter.api.Test;

public class RabbitMQRequeueQpidTest extends RabbitMQRequeueIntTest {
    @Override
    public boolean isStartDocker() {
        return false;
    }

    @BeforeAll
    public static void startBroker() throws Exception {
        systemLauncher.startup(createQpidSystemConfig());
    }

    @AfterAll
    public static void stopBroker() {
        systemLauncher.shutdown();
    }

    @Disabled
    @Override
    @Test
    public void testNoRequeueHeaderCausesReject() throws Exception {
    }

    @Disabled
    @Override
    @Test
    public void testNonBooleanRequeueHeaderCausesReject() throws Exception {
    }

    @Disabled
    @Override
    @Test
    public void testFalseRequeueHeaderCausesReject() throws Exception {
    }
}
